/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Specifies whether an entity should be cached if caching is enabled
/// when the value of the <c>persistence.xml</c> caching element
/// is <c>ENABLE_SELECTIVE</c> or <c>DISABLE_SELECTIVE</c>.
/// The value of the <c>Cacheable</c> annotation is inherited by
/// subclasses; it can be overridden by specifying
/// <c>Cacheable</c> on a subclass.
    ///<para>
///  <c>Cacheable(false)</c> means that the entity and its state must 
/// not be cached by the provider.
/// </para>
/// 
/// </summary>
[System.AttributeUsage(System.AttributeTargets.Class)]/*@Target( { TYPE })*/

public sealed class Cacheable : System.Attribute {

    /// <summary> (Optional) Whether or not the entity should be cached.
    /// </summary>
    public bool Value = true; 
    public Cacheable() {} 
    public Cacheable(bool value) { Value = value; } 
}
}