/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;




//import static NPersistence.EnumType.ORDINAL;

    /// <summary>
    /// Specifies that a persistent property or field should be persisted
    /// as a enumerated type.  The <c>Enumerated</c> annotation may
    /// be used in conjunction with the <c>Basic</c> annotation, or in
    /// conjunction with the <c>ElementCollection</c> annotation when the
    /// element collection value is of basic type. 
    /// <para>
    /// If the enumerated type
    /// is not specified or the <c>Enumerated</c> annotation is not
    /// used, the <c>EnumType</c> value is assumed to be <c>ORDINAL</c>.
    /// </para>
    /// <example><code>
    ///   Example:
    /// 
    ///   public enum EmployeeStatus {FULL_TIME, PART_TIME, CONTRACT}
    /// 
    ///   public enum SalaryRate {JUNIOR, SENIOR, MANAGER, EXECUTIVE}
    /// 
    ///   &#91;Entity&#93; public class Employee {
    ///       public EmployeeStatus getStatus() {...}
    ///       ...
    ///       &#91;Enumerated(STRING)&#93;
    ///       public SalaryRate getPayScale() {...}
    ///       ...
    ///   }
    /// </code></example>
    /// 
    /// <seealso cref="Basic"/>
    /// <seealso cref="ElementCollection"/>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)] 

public sealed class Enumerated : System.Attribute {

    /// <summary> (Optional) The type used in mapping an enum type.
    /// </summary>
    public EnumType Value = EnumType.ORDINAL; 
        public Enumerated() {} 
        public Enumerated(EnumType value) { Value = value; } 
}
}