/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;



    /// <summary> Is used to map the columns specified in the SELECT list 
    /// of the query to the properties or fields of the entity class.
    /// 
    /// <example><code>
    /// 
    /// Example:
    ///   Query q = em.createNativeQuery(
    ///       "SELECT o.id AS order_id, " +
    ///           "o.quantity AS order_quantity, " +
    ///           "o.item AS order_item, " +
    ///         "FROM Order o, Item i " +
    ///         "WHERE (order_quantity > 25) AND (order_item = i.id)",
    ///       "OrderResults");
    ///       
    ///   &#91;SqlResultSetMapping(name="OrderResults")&#93;
    ///           &#91;EntityResult(ResultSetRef = "OrderResults", Name="OrderEntityResult", EntityClass=com.acme.Order.class)&#93;
    ///               &#91;FieldResult(EntityRef = "OrderEntityResult", Name="id", Column="ordeR_ID")&#93;
    ///               &#91;FieldResult(EntityRef = "OrderEntityResult", Name="quantity", Column="order_quantity")&#93;
    ///               &#91;FieldResult(EntityRef = "OrderEntityResult", Name="item", Column="order_item")&#93;
    /// </code></example>
    /// 
    /// 
    /// </summary>
 


    [System.AttributeUsage(System.AttributeTargets.Class, AllowMultiple = true)]
    public sealed class FieldResult : System.Attribute {

        /// <summary>
        /// Required.
        /// Points to the EntityResult this FieldResult belongs to.
        /// </summary>
        public String EntityRef;

        /// <summary> Name of the persistent field or property of the class.
    /// </summary>
        public string Name;

        /// <summary> 
        /// Name of the column in the SELECT clause - i.e., column 
        /// aliases, if applicable. 
        /// </summary>
        public string Column;
    }
}