/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

    /// <summary> Provides for the specification of generation strategies for the
    /// values of primary keys. 
    /// <para>
    ///  The <c>GeneratedValue</c> annotation
    /// may be applied to a primary key property or field of an entity or
    /// mapped superclass in conjunction with the <see cref="Id"/> annotation.
    /// The use of the <c>GeneratedValue</c> annotation is only
    /// required to be supported for simple primary keys.  
    /// Use of the
    /// </para>
    /// <para>
    /// <c>GeneratedValue</c> annotation is not supported for derived
    /// primary keys.
    /// </para>
    /// <example><code>
    /// 
    ///     Example 1:
    /// 
    ///     &#91;Id&#93;
    ///     &#91;GeneratedValue(strategy=SEQUENCE, generator="CUST_SEQ")&#93;
    ///     &#91;Column(name="CUST_ID")&#93;
    ///     public Long getId() { return id; }
    /// 
    ///     Example 2:
    /// 
    ///     &#91;Id&#93;
    ///     &#91;GeneratedValue(strategy=TABLE, generator="CUST_GEN")&#93;
    ///     &#91;Column(name="CUST_ID")&#93;
    ///     Long id;
    /// </code></example>
    /// 
    /// <seealso cref="Id"/>
    /// <seealso cref="TableGenerator"/>
    /// <seealso cref="SequenceGenerator"/>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)]


public sealed class GeneratedValue : System.Attribute {

    /// <summary> (Optional) The primary key generation strategy
    /// that the persistence provider must use to
    /// generate the annotated entity primary key.
    /// </summary>
    public GenerationType Strategy = GenerationType.AUTO;

    /// <summary> (Optional) The name of the primary key generator
    /// to use as specified in the <see cref="SequenceGenerator"/> 
    /// or <see cref="TableGenerator"/> annotation.
    ///  Defaults to the id generator supplied by persistence provider.
    /// </summary>
    public string Generator = "";
}
}