/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


    /// <summary> Specifies the type of the map key for associations of type
    /// <c>System.Collections.Generic.Dictionary</c>.  
    /// <para>
    /// The map key can be a basic type, an
    /// embeddable class, or an entity. If the map is specified using
    /// generics, the <c>MapKeyClass</c> annotation and associated
    /// type need not be specified; otherwise they must be specified.
    /// </para><para>
    ///  The <c>MapKeyClass</c> annotation is used in conjunction
    /// with <c>ElementCollection</c> or one of the collection-valued
    /// relationship annotations (<c>OneToMany</c> or <c>ManyToMany</c>).
    /// The <c>MapKey</c> annotation is not used when
    /// <c>MapKeyClass</c> is specified and vice versa.
    /// </para>
    /// <example><code>
    /// 
    ///    Example 1:
    /// 
    ///    &#91;Entity&#93;
    ///    public class Item {
    ///       &#91;Id&#93; int id;
    ///       ...
    ///       &#91;ElementCollection(targetClass=String.class)&#93;
    ///       &#91;MapKeyClass(String.class)&#93;
    ///       Dictionary images;  // map from image name to image filename
    ///       ...
    ///    }
    /// 
    ///    Example 2:
    /// 
    ///    // MapKeyClass and target type of relationship can be defaulted
    /// 
    ///    &#91;Entity&#93;
    ///    public class Item {
    ///       &#91;Id&#93; int id;
    ///       ...
    ///       &#91;ElementCollection&#93;
    ///       Dictionary&#060;String, String&#062; images; 
    ///        ...
    ///     }
    /// 
    ///     Example 3:
    /// 
    ///     &#91;Entity&#93;
    ///     public class Company {
    ///        &#91;Id&#93; int id;
    ///        ...
    ///        &#91;OneToMany(targetEntity=com.example.VicePresident.class)&#93;
    ///        &#91;MapKeyClass(com.example.Division.class)&#93;
    ///        Dictionary organization;
    ///     }
    /// 
    ///     Example 4:
    /// 
    ///     // MapKeyClass and target type of relationship are defaulted
    /// 
    ///     &#91;Entity&#93;
    ///     public class Company {
    ///        &#91;Id&#93; int id;
    ///        ...
    ///        &#91;OneToMany&#93;
    ///        Dictionary&#060;Division, VicePresident&#062; organization;
    ///     }
    /// 
    /// </code></example>
    /// <seealso cref="ElementCollection "/>
    /// <seealso cref="OneToMany"/>
    /// <seealso cref="ManyToMany"/>
    /// 
    /// </summary>

    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)]/*@Target( { METHOD, FIELD })*/

public sealed class MapKeyClass : System.Attribute {
	/// <summary>(Required) The type of the map key.
    /// </summary>
	public System.Type Value; 
        public MapKeyClass() {} 
        public MapKeyClass(System.Type value) { Value = value; } 
}
}