/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

    /// <summary> Specifies the enum type for a map key whose basic type is an enumerated type.
    /// <para>
    /// The <c>MapKeyEnumerated</c> annotation can be applied to an 
    /// element collection or relationship of type <c>System.Collections.Generic.Dictionary</c>, in 
    /// conjunction with the <c>ElementCollection</c>, <c>OneToMany</c>, or 
    /// <c>ManyToMany</c> annotation.
    /// </para><para>
    /// 
    /// If the enumerated type is not specified or the <c>MapKeyEnumerated</c>
    /// annotation is not used, the enumerated type is assumed to be
    /// <c>ORDINAL</c>.
    /// </para>
    /// <example><code>
    ///   Example:
    /// 
    ///   public enum ProjectStatus {COMPLETE, DELAYED, CANCELLED, IN_PROGRESS}
    /// 
    ///   public enum SalaryRate {JUNIOR, SENIOR, MANAGER, EXECUTIVE}
    /// 
    ///   &#91;Entity&#93; public class Employee {
    ///       &#91;ManyToMany&#93; 
    ///       public Projects&#060;ProjectStatus, Project&#062; getProjects() {...}
    ///       
    ///       &#91;OneToMany&#93;
    ///       &#91;MapKeyEnumerated(STRING)&#93;
    ///       public Dictionary&#060;SalaryRate, Employee&#062; getEmployees() {...}
    ///       ...
    ///   }
    /// </code></example>
    /// 
    /// <seealso cref="ElementCollection"/>
    /// <seealso cref="OneToMany"/>
    /// <seealso cref="ManyToMany"/>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)] 
public sealed class MapKeyEnumerated : System.Attribute {
    
    /// <summary> (Optional) The type used in mapping a map key enum type.
    /// </summary>
    public EnumType Value = EnumType.ORDINAL; public MapKeyEnumerated() {} public MapKeyEnumerated(EnumType value) { Value = value; } 
}
}