/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

//import static NPersistence.LockModeType.NONE;



    /// <summary> 
    /// Specifies a static, named query in the Java Persistence query language.
    /// Query names are scoped to the persistence unit.
    /// <para>
    /// The <c>NamedQuery</c> annotation can be applied to an entity or mapped superclass.
    /// </para><para>
    ///  The following is an example of the definition of a named query 
    /// in the Java Persistence query language:
    /// </para>
    /// <example><code>
    ///    &#91;NamedQuery(
    ///            name="findAllCustomersWithName",
    ///            query="SELECT c FROM Customer c WHERE c.name LIKE :custName"&#93;
    ///    )
    /// </code></example>
    /// 
    ///  The following is an example of the use of a named query:
    /// 
    /// <example><code>
    ///    &#91;PersistenceContext&#93;
    ///    public EntityManager em;
    ///    ...
    ///    customers = em.createNamedQuery("findAllCustomersWithName")
    ///            .setParameter("custName", "Smith")
    ///            .getResultList();
    /// </code></example>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Class, AllowMultiple = true)] 

public sealed class NamedQuery : System.Attribute {

    /// <summary> 
    /// (Required) The name used to refer to the query with the <see cref="EntityManager"/> 
    /// methods that create query objects. 
    /// </summary>
    public string Name;

    /// <summary> (Required) 
    /// The query string in the Java Persistence query language. 
    /// </summary>
    public string Query;

    /// <summary> 
    /// (Optional) The lock mode type to use in query execution.  If a <c>lockMode</c>
    /// other than <c>LockModeType.NONE</c> is specified, the query must be executed in
    /// a transaction.
    /// 
    /// </summary>
    public LockModeType LockMode = LockModeType.NONE;
    
    /// <summary> (Optional) Query properties and hints.  May include
    /// vendor-specific query hints. 
    /// </summary>
    public QueryHint[] Hints = {};
}
}