/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


/// <summary> Specifies a column that is used to maintain the persistent order of
/// a list.
    /// <para>
    /// The persistence provider is responsible for maintaining the
/// order upon retrieval and in the database.
    /// </para><para>
    /// The persistence provider
/// is responsible for updating the ordering upon flushing to the
/// database to reflect any insertion, deletion, or reordering
/// affecting the list.
    /// </para><para>
///  The <c>OrderColumn</c> annotation is specified on a
/// OneToMany or ManyToMany relationship or on an element
/// collection. 
    /// </para><para>
    /// The <c>OrderColumn</c> annotation is specified on
/// the side of the relationship that references the collection that is
/// to be ordered. 
    /// </para><para>The order column is not visible as part of the state
/// of the entity or embeddable class.
    /// </para><para>
    ///  The <see cref="OrderBy"/> annotation should be used for ordering that
/// is visible as persistent state and maintained by the
/// application. 
    /// </para><para>
    /// The <c>OrderBy</c> annotation is not used when
/// <c>OrderColumn</c> is specified.
    /// </para><para>
///  The order column must be of integral type. 
    ///  </para><para>
    ///  The persistence
/// provider maintains a contiguous (non-sparse) ordering of the values
/// of the order column when updating the association or element collection.
    /// </para><para>
/// The order column value for the first element is 0.
/// </para>
/// <example><code>
/// 
///    Example:
/// 
///    &#91;Entity&#93;
///    public class CreditCard {
/// 
///       &#91;Id&#93; long ccNumber;
/// 
///       &#91;OneToMany&#93;  // unidirectional
///       &#91;OrderColumn&#93;
///       List&#060;CardTransaction&#062; transactionHistory;
///       ...
///    }
/// 
/// </code></example>
/// 
/// <seealso cref="OrderBy"/>
/// 
/// 
/// </summary>
[System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)]/*@Target( { METHOD, FIELD })*/

public sealed class OrderColumn : System.Attribute {

	/// <summary> (Optional) The name of the ordering column. 
        ///  Defaults to the concatenation of the name of the 
        ///  referencing property or field; "_"; "ORDER".
        /// </summary>
	public string Name = "";

	/// <summary> (Optional) Whether the database column is nullable.
    /// </summary>
	public bool Nullable = true;

	/// <summary> (Optional) Whether the column is included in SQL INSERT statements
	/// generated by the persistence provider.
	/// </summary>
	public bool Insertable = true;

	/// <summary> (Optional) Whether the column is included in SQL UPDATE statements
	/// generated by the persistence provider.
	/// </summary>
	public bool Updatable = true;

	/// <summary> (Optional) The SQL fragment that is used when generating the DDL for the
	/// column.  Defaults to generated SQL to create a column of the inferred type.
	/// </summary>
	public string ColumnDefinition = "";
}
}