/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> 
/// Thrown by the persistence provider when an pessimistic locking conflict
/// occurs.
    /// <para>
/// This exception may be thrown as part of an API call, a flush or at 
/// commit time. The current transaction, if one is active, will be marked for 
/// rollback.
    /// </para>
/// 
/// </summary>
public class PessimisticLockException : PersistenceException {
    /// <summary> The object that caused the exception
    /// </summary>
    internal object entity;

    /// <summary> 
    /// Constructs a new <c>PessimisticLockException</c> exception 
    /// with <c>null</c> as its detail message.
    /// </summary>
    public PessimisticLockException() : base() {
        // super(...) -> base(...)
    }

    /// <summary> 
    /// Constructs a new <c>PessimisticLockException</c> exception 
    /// with the specified detail message.
    /// </summary>
    /// <param name="message">the detail message.</param>
    
    public PessimisticLockException(string message) : base(message) {
        // super(...) -> base(...)
    }

    /// <summary> 
    /// Constructs a new <c>PessimisticLockException</c> exception 
    /// with the specified detail message and cause.
    /// </summary>
    /// <param name="message">the detail message.</param>
    /// <param name="cause">the cause.</param>
    
    public PessimisticLockException(string message, System.Exception cause) : base(message, cause) {
        // super(...) -> base(...)
    }

    /// <summary> 
    /// Constructs a new <c>PessimisticLockException</c> exception 
    /// with the specified cause.
    /// </summary>
    /// <param name="cause">the cause.</param>
    
    public PessimisticLockException(System.Exception cause) : base(cause) {
        // super(...) -> base(...)
    }

    /// <summary> 
    /// Constructs a new <c>PessimisticLockException</c> exception 
    /// with the specified entity.
    /// </summary>
    /// <param name="entity">the entity.</param>s
    
    public PessimisticLockException(object entity) {
        this.entity = entity;
    }

    /// <summary> 
    /// Constructs a new <c>PessimisticLockException</c> exception 
    /// with the specified detail message, cause, and entity.
    /// </summary>
    /// <param name="message">the detail message.</param>
    /// <param name="cause">  the cause.</param>
    /// <param name="entity"> the entity.</param>
    
    public PessimisticLockException(string message, System.Exception cause, object entity) : base(message, cause) {
        // super(...) -> base(...)
        this.entity = entity;
    }
    
    /// <summary> Returns the entity that caused this exception.
    /// </summary>
    /// <returns> the entity.</returns>
    
    public object GetEntity() {
        return this.entity;
    }
}



}