/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


/// <summary> Specifies a secondary table for the annotated entity
/// class. 
    /// <para>
/// Specifying one or more secondary tables indicates that the
/// data for the entity class is stored across multiple tables.
    /// </para><para>
///  If no <c>SecondaryTable</c> annotation is specified, 
/// it is assumed that all persistent fields or properties of the 
/// entity are mapped to the primary table. 
    /// </para><para>If no primary key join 
/// columns are specified, the join columns are assumed to reference 
/// the primary key columns of the primary table, and have the same 
/// names and types as the referenced primary key columns of the 
/// primary table.</para>
/// 
/// <example><code>
///    Example 1: Single secondary table with a single primary key column.
/// 
///    &#91;Entity&#93;
///    &#91;Table(name="CUSTOMER")&#93;
///    &#91;SecondaryTable(name="CUST_DETAIL")&#93;
///        &#91;PrimaryKeyJoinColumn(name="CUST_ID")&#93;
///    public class Customer { ... } 
/// 
/// 
///    Example 2: Single secondary table with multiple primary key columns.
/// 
///    &#91;Entity&#93;
///    &#91;Table(name="CUSTOMER")&#93;
    ///    &#91;SecondaryTable(name="CUST_DETAIL")&#93;
    ///            &#91;PrimaryKeyJoinColumn(name="CUST_ID")&#93;
    ///            &#91;PrimaryKeyJoinColumn(name="CUST_TYPE")&#93;
///    public class Customer { ... }
/// </code></example>
/// 
/// 
/// </summary>
    [System.AttributeUsage(System.AttributeTargets.Class, AllowMultiple = true)]/*@Target(TYPE)*/ 


public sealed class SecondaryTable : System.Attribute {

    /// <summary> (Required) The name of the table.
    /// </summary>
    public string Name;

    /// <summary> (Optional) The catalog of the table.
    ///  Defaults to the default catalog.
    /// </summary>
    public string Catalog = "";

    /// <summary> (Optional) The schema of the table.
    ///  Defaults to the default schema for user.
    /// </summary>
    public string Schema = "";

}
}