/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


    /// <summary> Specifies the primary table for the annotated entity. 
    /// <para>
    /// Additional
    /// tables may be specified using <see cref="SecondaryTable"/> annotation.
    /// </para><para>
    ///  If no <c>Table</c> annotation is specified for an entity 
    /// class, the default values apply.
    /// </para>
    /// <example><code>
    ///    Example:
    /// 
    ///    &#91;Entity&#93;
    ///    &#91;Table(name="CUST", schema="RECORDS")&#93;
    ///    public class Customer { ... }
    /// </code></example>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Class)]/*@Target(TYPE)*/ 

public sealed class Table : System.Attribute {

    /// <summary> (Optional) The name of the table.
    ///  Defaults to the entity name
    ///  </summary>
    public string Name = "";

    /// <summary> (Optional) The catalog of the table.
    ///  Defaults to the default catalog
    ///  </summary>
    public string Catalog = "";

    /// <summary> (Optional) The schema of the table.
    ///  Defaults to the default schema for user
    ///  </summary>
    public string Schema = "";

}
}