﻿namespace NPersistence.Ext/*javax.jdo.annotations*/ 
{
    using System;
    using System.Reflection;
    using System.Collections;
    using System.Collections.Generic;

    /// <summary>
    /// Specifies that an index should be placed on the column or group of columns.
    /// 
    /// <example><code>
    ///    Example 1:
    ///    2 different indices for the 2 columns
    ///    &#91;Index&#93;
    ///    public String getName() { return name; }
    ///    
    ///    &#91;Index&#93;
    ///    public String getDescription() { return description; }
    /// 
    ///    Example 2:
    ///    Both columns included in one index.
    ///    &#91;Index(Name="ix1")&#93;
    ///    public String getName() { return name; }
    ///    
    ///    &#91;Index(Name="ix1")&#93;
    ///    public String getDescription() { return description; }
    ///    
    ///    Example 3:
    ///    The Index annotation is defined at the Entity level
    ///    &#91;Index(Name="ix1", Members=new String[]{"name", "description"})&#93;
    ///    &#91;Entity&#93;
    ///    public class Person
    ///    ...
    ///    public String getName() { return name; }
    ///    public String getDescription() { return description; }
    /// 
    /// </code></example>
    /// </summary>

    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property | AttributeTargets.Class)]
    public sealed class Index : System.Attribute
    {
        /// <summary>
        /// (Optional) Name of the index, if not specified defaults to a generated index name given by the vendor.
        /// Default value:
        /// ""
        /// </summary>
        public String Name = "";

        /// <summary>
        /// Member names that compose this index.
        /// Relevant only when the Index annotation is used on a class.
        /// Returns:
        /// member names that compose this index
        /// </summary>
        public String[] Members;

    }
}