/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence.spi { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> A persistence provider supplies an instance of this 
    /// interface to the <see cref="M:PersistenceUnitInfo.AddTransformer"/>
/// method. The supplied transformer instance will get 
/// called to transform entity class files when they are 
/// loaded or redefined. The transformation occurs before  
/// the class is defined by the JVM.
/// 
/// </summary>
public interface ClassTransformer {

    /// <summary> Invoked when a class is being loaded or redefined.
    /// The implementation of this method may transform the 
    /// supplied class file and return a new replacement class 
    /// file.
    /// 
    /// </summary>
    /// <param name="loader">  the defining loader of the class to be 
    ///        transformed, may be null if the bootstrap loader</param>
    /// <param name="className">  the name of the class in the internal form 
    ///        of fully qualified class and interface names </param>
    /// <param name="classBeingRedefined">  if this is a redefine, the 
    ///        class being redefined, otherwise null</param>
    /// <param name="protectionDomain">  the protection domain of the 
    ///        class being defined or redefined</param>
    /// <param name="classfileBuffer">  the input byte buffer in class 
    ///        file format - must not be modified </param>
    /// <returns> a well-formed class file buffer (the result of 
    ///         the transform), or null if no transform is performed</returns>
    ///         
    /// <throws> IllegalClassFormatException  if the input does 
    ///         not represent a well-formed class file</throws>
    ///         
    
    //byte[] Transform(System.Reflection.Assembly loader,
    //                 string className,
    //                 System.Type classBeingRedefined,
    //                 ProtectionDomain protectionDomain, 
    //                 byte[] classfileBuffer) 
    //    ;
}
}